### Name: btgp
### Title: Bayesian Nonparametric & Nonstationary Regression Models
### Aliases: blm btlm bcart bgp bgpllm btgp btgpllm
### Keywords: nonparametric nonlinear smooth models regression spatial tree

### ** Examples

##
## Many of the examples below illustrate the above 
## function(s) on random data.  Thus it can be fun
## (and informative) to run them several times.
##

# 
# simple linear response
#

# input and predictive data
X <- seq(0,1,length=50)
XX <- seq(0,1,length=99)
Z <- 1 + 2*X + rnorm(length(X),sd=0.25)

out <- blm(X=X, Z=Z, XX=XX)     # try Linear Model
plot(out)                       # plot the surface

#
# 1-d Example
# 

# construct some 1-d nonstationary data
X <- seq(0,20,length=100)
XX <- seq(0,20,length=99)
Z <- (sin(pi*X/5) + 0.2*cos(4*pi*X/5)) * (X <= 9.6)
lin <- X>9.6; 
Z[lin] <- -1 + X[lin]/10
Z <- Z + rnorm(length(Z), sd=0.1)

out <- btlm(X=X, Z=Z, XX=XX)    # try Linear CART
plot(out)                       # plot the surface
tgp.trees(out)                  # plot the MAP trees

out <- btgp(X=X, Z=Z, XX=XX)    # use a treed GP
plot(out)                       # plot the surface
tgp.trees(out)                  # plot the MAP trees

#
# 2-d example
# (using the isotropic correlation function)
#

# construct some 2-d nonstationary data
exp2d.data <- exp2d.rand()
X <- exp2d.data$X; Z <- exp2d.data$Z
XX <- exp2d.data$XX

# try a GP
out <- bgp(X=X, Z=Z, XX=XX, corr="exp")         
plot(out)                       # plot the surface

# try a treed GP LLM
out <- btgpllm(X=X, Z=Z, XX=XX, corr="exp") 
plot(out)                       # plot the surface
tgp.trees(out)                  # plot the MAP trees

#
# Motorcycle Accident Data
#

# get the data
require(MASS)

# try a GP 
out <- bgp(X=mcycle[,1], Z=mcycle[,2])
plot(out)                       # plot the surface

# try a treed GP LLM
# best to use the "b0" beta linear prior to capture common
# common linear process throughout all regions (using the
# ellipses "...") 
out <- btgpllm(X=mcycle[,1], Z=mcycle[,2], bprior="b0")
plot(out)                       # plot the surface
tgp.trees(out)                  # plot the MAP trees

##
## Begin Multi-resolution TGP (mrtgp) examples
##

# Two-Fidelity model with corr="mrexpsep", 1D example:
# Fit and plot a simple 2 resolution model where we
# have very little 'fine' level data.
N <- 25
X <- runif(N)
Y <- 2*X
ind <- sample(c(0,1),N,prob=c(.7,.3),replace=TRUE)
Z <- Y + ind*sin(12*X)*.75 + rnorm(N,0,.1)
b <- btgp(X=cbind(ind,X), Z=Z, XX=cbind(rep(1,40),
          seq(0,1,length=40)), corr="mrexpsep",
          BTE=c(5000,10000,10))
plot(b)

# Fit a standard tgp to the 'fine' data only, and plot
# the fit for comparison.
Xf <- X[ind==1]
Zf <- Z[ind==1]
bf <- btgp(Xf, Zf, XX=seq(0,1,length=40), corr="expsep")
points(Xf, Zf)
lines(bf$XX[,1], bf$ZZ.mean, lty=1, col=3)
lines(bf$XX[,1], bf$ZZ.q1, lty=3, col=3)
lines(bf$XX[,1], bf$ZZ.q2, lty=3, col=3)

# Two-Fidelity model with corr="mrexpsep", 2D example:
# Use the exp2d data as the coarse function, and add
# a sin term to get the fine level.
N <- 45
exp2d.data <- exp2d.rand(n1=30, n2=15, lh=200)
X <- exp2d.data$X; Z <- exp2d.data$Z
XX <- cbind(ind=rep(1,200), exp2d.data$XX)
XX <- rbind(XX, cbind(ind=rep(0,200), exp2d.data$XX))
ind <- sample(c(0,1),N,prob=c(.7,.3),replace=TRUE)
Z <- Z + (ind/10)*sin(X[,1]*X[,2])
b2 <- btgp(X=cbind(ind,X), Z=Z, XX=XX, corr="mrexpsep",
           meanfn="constant")

# Plots focusing on the different resolutions
plot(b2, legendloc="topleft") # Plot both fine and coarse fits.
plot(b2, mrlayout="fine") # Plot fine only.
plot(b2, mrlayout="coarse") # Plot coarse only.



